"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DenoBuilder = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const framework_core_1 = require("@cloudbase/framework-core");
class DenoBuilder extends framework_core_1.Builder {
    constructor(options) {
        super(Object.assign({ type: 'deno' }, options));
    }
    build(localDir, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const { distDir, projectDir } = this;
            const containerName = (options === null || options === void 0 ? void 0 : options.name) || 'deno-app';
            const appDir = path_1.default.join(distDir, containerName);
            const spec = Object.assign({}, options);
            spec.denoVersion = '';
            if (spec.runtime && spec.runtime !== 'latest') {
                spec.denoVersion = `-s ${spec.runtime}`;
            }
            fs_extra_1.default.ensureDirSync(appDir);
            yield Promise.all([
                this.generator.generate(path_1.default.join(__dirname, '../assets'), appDir, spec),
                fs_extra_1.default.copy(path_1.default.join(projectDir, localDir), appDir),
            ]);
            return {
                containers: [
                    {
                        name: containerName,
                        options: {},
                        source: appDir,
                    },
                ],
                routes: [
                    {
                        path: options.path,
                        targetType: 'container',
                        target: containerName,
                    },
                ],
            };
        });
    }
}
exports.DenoBuilder = DenoBuilder;
